==> plone.rest-2.0.0a4.tar.gz: plone.rest-2.0.0a4/setup.py <==
import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()


version = "2.0.0a4"

long_description = read("README.rst") + "\n\n" + read("CHANGES.rst") + "\n\n"


setup(
    name="plone.rest",
    version=version,
    description="Plone support for HTTP verbs.",
    long_description=long_description,
    # Get more strings from
    # https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 4.3",
        "Framework :: Plone :: 5.0",
        "Framework :: Plone :: 5.1",
        "Framework :: Plone :: 5.2",
        "Framework :: Plone :: Core",
        "Framework :: Zope2",
        "Framework :: Zope :: 4",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    keywords="rest http",
    author="Plone Foundation",
    author_email="plone-developers@lists.sourceforge.net",
    url="https://github.com/plone/plone.rest/",
    license="GPL version 2",
    packages=find_packages("src"),
    package_dir={"": "src"},
    namespace_packages=["plone"],
    include_package_data=True,
    zip_safe=False,
    extras_require=dict(
        test=[
            "plone.app.testing[robot]>=4.2.2",
            "plone.app.robotframework",
            "plone.dexterity",
            "Products.CMFCore",
            "requests",
        ]
    ),
    install_requires=[
        "setuptools",
        "collective.monkeypatcher",
        "zope.component",
        "zope.interface",
        "zope.publisher",
        "zope.traversing",
        "Products.CMFCore",
        "Zope2",
        "six",
    ],
    entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
)

==> plone.rest-3.0.0.tar.gz: plone.rest-3.0.0/setup.py <==
import os

from setuptools import find_packages, setup


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()


version = "3.0.0"

long_description = read("README.rst") + "\n\n" + read("CHANGES.rst") + "\n\n"


setup(
    name="plone.rest",
    version=version,
    description="Plone support for HTTP verbs.",
    long_description=long_description,
    # Get more strings from
    # https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Framework :: Plone :: 5.2",
        "Framework :: Plone :: 6.0",
        "Framework :: Plone :: Core",
        "Framework :: Zope2",
        "Framework :: Zope :: 4",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    keywords="rest http",
    author="Plone Foundation",
    author_email="plone-developers@lists.sourceforge.net",
    url="https://github.com/plone/plone.rest/",
    license="GPL version 2",
    packages=find_packages("src"),
    package_dir={"": "src"},
    namespace_packages=["plone"],
    include_package_data=True,
    zip_safe=False,
    python_requires=">=2.7",
    extras_require=dict(
        test=[
            "plone.app.testing[robot]>=4.2.2",
            "plone.app.robotframework",
            "plone.dexterity",
            "Products.CMFCore",
            "requests",
        ]
    ),
    install_requires=[
        "setuptools",
        "collective.monkeypatcher",
        "zope.component",
        "zope.interface",
        "zope.publisher",
        "zope.traversing",
        "Products.CMFCore",
        "Zope2",
        "six",
    ],
    entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
)
